==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GdkPixbufDecoder__24GdkPixbufReaderSpi.h <==
// public class gnu.java.awt.peer.gtk.GdkPixbufDecoder$GdkPixbufReaderSpi

// class file dependencies
// @dep_class 20ec764079b90763 gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 8a1457f27fe020d8 javax_imageio_spi_ImageReaderSpi
// @dep_class a9d92a58c03c7752 javax_imageio_spi_ImageReaderWriterSpi

// header file dependencies
// @dep_header javax_imageio_spi_ImageReaderSpi

#include "javax/imageio/spi/ImageReaderSpi.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi_H_
#define _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;
struct _jc_javax_imageio_ImageReader$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24stream__24ImageInputStream;
};
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *);

// Virtual methods
extern jboolean _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$canDecodeInput$ff527f85db0017c6(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_javax_imageio_ImageReader$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$createReaderInstance$e1f65a39e6c08f5e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$getDescription$e653ca2170cc9e26(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_util_Locale$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method_info$canDecodeInput$ff527f85db0017c6;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method_info$createReaderInstance$e1f65a39e6c08f5e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method_info$getDescription$e653ca2170cc9e26;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean);

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods {
	jboolean	(*canDecodeInput$ff527f85db0017c6)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *);
	struct _jc_javax_imageio_ImageReader$object	*(*createReaderInstance$e1f65a39e6c08f5e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*getDescription$e653ca2170cc9e26)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_util_Locale$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageReaderWriterSpi$vmethods	javax_imageio_spi_ImageReaderWriterSpi;
	_jc_javax_imageio_spi_ImageReaderSpi$vmethods	javax_imageio_spi_ImageReaderSpi;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs {
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi;
    _jc_javax_imageio_spi_ImageReaderSpi$sub_refs	javax_imageio_spi_ImageReaderSpi;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_refs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_nonrefs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_ImageReaderSpi$sub_nonrefs	javax_imageio_spi_ImageReaderSpi;
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object {
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GdkPixbufDecoder__24GdkPixbufReaderSpi.h <==
// public class gnu.java.awt.peer.gtk.GdkPixbufDecoder$GdkPixbufReaderSpi

// class file dependencies
// @dep_class 20ec764079b90763 gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3de402a610fa78c4 javax_imageio_spi_IIOServiceProvider
// @dep_class 8a1457f27fe020d8 javax_imageio_spi_ImageReaderSpi
// @dep_class a9d92a58c03c7752 javax_imageio_spi_ImageReaderWriterSpi

// header file dependencies
// @dep_header javax_imageio_spi_ImageReaderSpi

#include "javax/imageio/spi/ImageReaderSpi.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi_H_
#define _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Locale$object;
struct _jc_javax_imageio_ImageReader$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object;

typedef struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype;

// Class fields structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct {
	struct _jc_java_lang_Class$object	*class__24javax__24imageio__24stream__24ImageInputStream;
};
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$fields_struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$class_fields;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$canDecodeInput$ff527f85db0017c6(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_javax_imageio_ImageReader$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$createReaderInstance$e1f65a39e6c08f5e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$getDescription$e653ca2170cc9e26(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method_info$canDecodeInput$ff527f85db0017c6;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method_info$createReaderInstance$e1f65a39e6c08f5e;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method_info$getDescription$e653ca2170cc9e26;

// Static methods
extern struct _jc_java_lang_Class$object *_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$method$class$c900dc17c9967b78(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods {
	jboolean	(*canDecodeInput$ff527f85db0017c6)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_javax_imageio_ImageReader$object	*(*createReaderInstance$e1f65a39e6c08f5e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getDescription$e653ca2170cc9e26)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object *, struct _jc_java_util_Locale$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_imageio_spi_IIOServiceProvider$vmethods	javax_imageio_spi_IIOServiceProvider;
	_jc_javax_imageio_spi_ImageReaderWriterSpi$vmethods	javax_imageio_spi_ImageReaderWriterSpi;
	_jc_javax_imageio_spi_ImageReaderSpi$vmethods	javax_imageio_spi_ImageReaderSpi;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vmethods	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs {
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_refs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi;
    _jc_javax_imageio_spi_ImageReaderSpi$sub_refs	javax_imageio_spi_ImageReaderSpi;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_refs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_refs	javax_imageio_spi_IIOServiceProvider;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_imageio_spi_IIOServiceProvider$sub_nonrefs	javax_imageio_spi_IIOServiceProvider;
    _jc_javax_imageio_spi_ImageReaderWriterSpi$sub_nonrefs	javax_imageio_spi_ImageReaderWriterSpi;
    _jc_javax_imageio_spi_ImageReaderSpi$sub_nonrefs	javax_imageio_spi_ImageReaderSpi;
    _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$sub_nonrefs	gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$object {
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$vtype _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GdkPixbufDecoder__24GdkPixbufReaderSpi_H_ */
